
# Slot: object


a disease that is associated with that variant

URI: [biolink:variant_to_disease_association_object](https://w3id.org/biolink/vocab/variant_to_disease_association_object)


## Domain and Range

[VariantToDiseaseAssociation](VariantToDiseaseAssociation.md) &#8594;  <sub>1..1</sub> [NamedThing](NamedThing.md)

## Parents

 *  is_a: [object](object.md)

## Children


## Used by

 * [VariantAsAModelOfDiseaseAssociation](VariantAsAModelOfDiseaseAssociation.md)
 * [VariantToDiseaseAssociation](VariantToDiseaseAssociation.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Local names:** | | descriptor (ga4gh) |
|  | | node with incoming relationship (neo4j) |
| **Mappings:** | | rdf:object |
| **Examples:** | | Example(value='MONDO:0016419', description='hereditary breast cancer') |
| **Exact Mappings:** | | owl:annotatedTarget |
|  | | OBAN:association_has_object |

